from __future__ import absolute_import

EXTENSION = '.yaml'


def dump(obj, f, *args, **kwargs):
    from baiji.serialization.util.openlib import ensure_file_open_and_call
    return ensure_file_open_and_call(f, _dump, 'w', obj, *args, **kwargs)


def load(f, *args, **kwargs):
    from baiji.serialization.util.openlib import ensure_file_open_and_call
    return ensure_file_open_and_call(f, _load, 'r', *args, **kwargs)


def loads(s, *args, **kwargs):
    import yaml
    return yaml.load(s, *args, **kwargs)


def dumps(obj, *args, **kwargs):
    import yaml
    return yaml.dump(obj, *args, **kwargs)


def _dump(f, obj, *args, **kwargs):
    import yaml
    return yaml.dump(obj, f, *args, **kwargs)


def _load(f, *args, **kwargs):
    import yaml
    return yaml.load(f, *args, **kwargs)



from __future__ import absolute_import
import simplejson as json

EXTENSION = '.json'

def dump(obj, f, *args, **kwargs):
    from baiji.serialization.util.openlib import ensure_file_open_and_call
    return ensure_file_open_and_call(f, _dump, 'w', obj, *args, **kwargs)

def load(f, *args, **kwargs):
    from baiji.serialization.util.openlib import ensure_file_open_and_call
    return ensure_file_open_and_call(f, _load, 'r', *args, **kwargs)

def loads(*args, **kwargs):
    return json.loads(*args, **kwargs)

def dumps(*args, **kwargs):
    kwargs.update(for_json=True)
    return json.dumps(*args, **kwargs)

def _dump(f, obj, *args, **kwargs):
    kwargs.update(for_json=True)
    return json.dump(obj, f, *args, **kwargs)

def _load(f, *args, **kwargs):
    return json.load(f, *args, **kwargs)



def ensure_file_open_and_call(path_or_fp, fn, mode='r', *args, **kwargs):
    from baiji import s3

    if isinstance(path_or_fp, basestring):
        with s3.open(path_or_fp, mode) as f:
            return fn(f, *args, **kwargs)
    elif isinstance(path_or_fp, file) or (hasattr(path_or_fp, 'read') and hasattr(path_or_fp, 'seek')):
        result = fn(path_or_fp, *args, **kwargs)
        if hasattr(path_or_fp, 'flush'):
            path_or_fp.flush()
        return result
    else:
        raise ValueError('Object {} does not appear to be a path or a file like object'.format(path_or_fp))
